@@ -2,7 +2,7 @@ import numpy as np
 import rasterio
 import pyproj
 
-def interpolate_from_raster(raster, col="topo", projection=None, **tri):
+def interpolate_from_raster(raster, col="topo", projection=None, overwrite_existing=True, **tri):
     """Sample vertice data from a raster image. Coordinate reprojection is
     done using the crs of the raster and the supplied projection or
     tri["meta"]["projection"].
@@ -22,13 +22,16 @@ def interpolate_from_raster(raster, col="topo", projection=None, **tri):
     #UTM convention is coordinate order Northing-Easting. CCh, 2020-06-18
     xy = np.column_stack(
         pyproj.Transformer.from_crs(int(projection), raster.crs.to_epsg(), always_xy=True
-        ).transform(tri["vertices"]["X"], tri["vertices"]["Y"]))
+        ).transform(tri["vertices"]["X"].values, tri["vertices"]["Y"].values))
     
     filt = (  (xy[:,0] >= raster.bounds.left) & (xy[:,0] <= raster.bounds.right)
             & (xy[:,1] >= raster.bounds.bottom) & (xy[:,1] <= raster.bounds.top))
+    if not overwrite_existing:
+        filt = filt & tri['vertices'][col].isna().values
     filt = tri["vertices"].index[filt].values
 
-    sampled = np.array(list(raster.sample(xy[filt,:])))[:,0]
+
+    sampled = np.array(list(raster.sample([tuple(l) for l in xy[filt,:]])))[:,0]
     datafilt = ~np.isin(sampled, raster.get_nodatavals())
 
     filt = filt[datafilt]
