@@ -20,14 +20,9 @@ def replace_triangles(points, vertices=None, triangles=None, **tri):
     #       Maybe the most proper approach would be to replace lines of `vertices` with those of `points`...
     #       or at least users should have the choice of which one should be overwritten.
     #       2021-09-02, Duke-of-Lizard
-    points = points.drop_duplicates(['X','Y'])
-
-    p_xy = points.loc[:, ['X', 'Y']]
-    v_xy = vertices.loc[:, ['X', 'Y']]
-    merged_pv = pd.merge(p_xy, v_xy, on=['X', 'Y'], how='left', indicator='indicator')
-    merged_pv['duplicated_flag'] = np.where(merged_pv.loc[:, 'indicator'] == 'both', True, False)
-    points = points[~ merged_pv['duplicated_flag']]
+    points = points.drop_duplicates(['X','Y']).reset_index(drop=True)
 
+    points, vertices = cleanup.remove_overlapping_points_vertices(points, vertices, keep='points')
 
     points_start = len(vertices)
     points_and_nodes = vertices.append(points).reset_index(drop=True)
@@ -176,6 +171,9 @@ def interpolate_vertices(tri, to_interpolate_idxs):
     segments2["segment_weight"] = 1. / segments2["segment_length"]
     segments2 = segments2[~segments2[0].isin(new_points)]
 
+    # We can only interpolate floats...
+    segments2 = segments2[segments2.dtypes.index[segments2.dtypes == float]]
+    
     segments3 = segments2.mul(
         segments2["segment_weight"], axis=0
     ).assign(
@@ -184,8 +182,10 @@ def interpolate_vertices(tri, to_interpolate_idxs):
 
     interpolated = segments3.div(segments3["segment_weight"], axis=0)
 
+    no_interpolation = set(("X", "Y")).union(set(tri.get("no_interpolation", ())))
+    
     res = dict(tri)
     res["vertices"] = res["vertices"].copy()
-    cols = set(interpolated.columns).intersection(set(tri["vertices"].columns)) - set(("X", "Y"))
+    cols = set(interpolated.columns).intersection(set(tri["vertices"].columns)) - no_interpolation
     res["vertices"].loc[interpolated.index, cols] = interpolated[cols]
     return res
